==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/ruleoptionplugins/nat_target_option/kmfruletargetoptioneditnat.h <==
/***************************************************************************
    Copyright (C) 2004 Christian Hubinger
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@gmail.com>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITNAT_H
#define KMFRULETARGETOPTIONEDITNAT_H

#include "../../interfaces/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>


class IPTRule;
class KMFRuleEditorTargetNat;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditNat : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
public:
	KMFRuleTargetOptionEditNat(QObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditNat();
	void loadRule( IPTRule* rule );	
	QWidget* editWidget();
	const QString& optionEditName() const;
	const QString& description() const;
	bool setTarget( const QString& );

private slots:
	void slotAddRuleOption(QString*, QPtrList< QString >* );
	void slotAddTargetOption(QString*, QPtrList< QString >* );
	void slotShowOverview();

private:
	KMFRuleEditorTargetNat *m_edit;
	IPTRule *m_rule;
	
};

class KInstance;

class KMFRuleTargetOptionEditNatFactory : public KLibFactory {
	Q_OBJECT
public:
	KMFRuleTargetOptionEditNatFactory( QObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditNatFactory() {
/* 		delete s_instance; */
	};
	virtual QObject* createObject( QObject* parent = 0, const char* pname = 0,
	                               const char* name = "QObject",
	                               const QStringList &args = QStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};









#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/ruleoptionplugins/nat_target_option/kmfruletargetoptioneditnat.h <==
/***************************************************************************
    Copyright (C) 2004 Christian Hubinger
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITNAT_H
#define KMFRULETARGETOPTIONEDITNAT_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>
class KInstance;
namespace KMF {
class IPTRule;
class KMFRuleEditorTargetNat;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditNat : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
public:
	KMFRuleTargetOptionEditNat(QObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditNat();
	void loadRule( IPTRule* rule );	
	QWidget* editWidget();
	const QString& optionEditName() const;
	const QString& description() const;
	bool setTarget( const QString& );

private slots:
	void slotShowOverview();

private:
	KMFRuleEditorTargetNat *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditNatFactory : public KLibFactory {
	Q_OBJECT
public:
	KMFRuleTargetOptionEditNatFactory( QObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditNatFactory() {
/* 		delete s_instance; */
	};
	virtual QObject* createObject( QObject* parent = 0, const char* pname = 0,
	                               const char* name = "QObject",
	                               const QStringList &args = QStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};
}








#endif
